@@ -1,7 +1,7 @@
 import random
 
 
-def createID(length=3):
+def createID(length=3, modulo=10):
     n = ""
     cd = 0
     digits = []
@@ -13,9 +13,12 @@ def createID(length=3):
     for i in range(length - 1, 0, -1):
         cd = cd + (digits[i - 1] * i)
 
-    cd = cd % 10
+    cd = cd % modulo
     for i in range(0, length - 1):
         id = id + str(digits[i])
 
     id = id + str(cd)
-    return(id)
+    if len(id) == length:
+        return (id)
+    else:
+        return createID(length, modulo)
